@@ -1,7 +1,7 @@
 package Net::SAML2::Binding::Redirect;
 use Moose;
 
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 use Carp qw(croak);
 use Crypt::PK::RSA;
@@ -212,7 +212,7 @@ Net::SAML2::Binding::Redirect - HTTP Redirect binding for SAML
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -324,23 +324,13 @@ case (or mixed case).
 Returns an ARRAY of containing the verified request and relaystate (if it exists).
 Croaks on errors.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
