@@ -1,7 +1,7 @@
 package Net::SAML2::Binding::SOAP;
 use Moose;
 
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common;
@@ -236,7 +236,7 @@ Net::SAML2::Binding::SOAP - SOAP binding for SAML
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -325,23 +325,13 @@ Accepts a string containing the complete SOAP request.
 
 Signs and SOAP-wraps the given message.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
