@@ -1,7 +1,7 @@
 package Net::SAML2::Object::Response;
 use Moose;
 
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 use overload '""' => 'to_string';
 
@@ -127,7 +127,7 @@ Net::SAML2::Object::Response - A response object
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -187,23 +187,13 @@ Stringify the object to the full response XML
 Create a L<Net::SAML2::Protocol::Assertion> from the response. See
 L<Net::SAML2::Protocol::Assertion/new_from_xml> for more.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
