@@ -1,6 +1,6 @@
 package Net::SAML2::Role::VerifyXML;
 use Moose::Role;
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 use Net::SAML2::XML::Sig;
 use Crypt::OpenSSL::Verify;
@@ -81,7 +81,7 @@ Net::SAML2::Role::VerifyXML - A role to verify the SAML response XML
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 SYNOPSIS
 
@@ -128,23 +128,13 @@ version 0.83
         },
     );
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
