@@ -1,7 +1,7 @@
 package Net::SAML2::Role::XMLLang;
 use Moose::Role;
 
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 # ABSTRACT: Common behaviour for XML language settings
 
@@ -34,7 +34,7 @@ Net::SAML2::Role::XMLLang - Common behaviour for XML language settings
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 CONSTRUCTOR ARGUMENTS
 
@@ -46,23 +46,13 @@ Set the language, defaults to English (C<en>).
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
