@@ -8,7 +8,7 @@
 use strict;
 use warnings;
 package Net::SAML2::XML::Sig; use base qw(XML::Sig);
-our $VERSION = '0.83'; #VERSION
+our $VERSION = '0.84'; #VERSION
 #
 # ABSTRACT: Net::SAML2 subclass of XML::Sig
 #
@@ -27,25 +27,15 @@ Net::SAML2::XML::Sig - Net::SAML2 subclass of XML::Sig
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Chris Andrews  <chrisa@cpan.org>
-
-=item *
+=head1 AUTHOR
 
 Timothy Legge <timlegge@gmail.com>
 
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2025 by Venda Ltd, see the CONTRIBUTORS file for others.
+This software is copyright (c) 2026 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
